/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.internal.ftp.client;

import java.util.Date;
import java.util.StringTokenizer;

import org.eclipse.team.internal.ftp.FTPException;

/**
 * Factory for converting an EPLF line to an FTPFDirectoryEntry
 */
public class EPLFDirectoryEntryParser extends DirectoryEntryParser {

	/* (non-Javadoc)
	 * @see org.eclipse.team.internal.ftp.client.FTPDirectoryEntryFactory#createEntry(java.lang.String)
	 */
	public FTPDirectoryEntry parseEntry(String line) throws FTPException {
		if (line.charAt(0) != '+') return null;
		try {
			boolean hasDirectorySemantics = false;
			boolean hasFileSemantics = false;
			long size = FTPDirectoryEntry.UNKNOWN_SIZE;
			Date modTime = null;
			String filename = null;
			StringTokenizer tok = new StringTokenizer(line.substring(1), ",\t", true); //$NON-NLS-1$
			while (tok.hasMoreTokens()) {
				String token = tok.nextToken();
				if (token.length() == 0) continue;
				switch (token.charAt(0)) {
					case 'r': // can RETR
						hasFileSemantics = true;
						break;
					case '/': // can CWD
						hasDirectorySemantics = true;
						break;
					case 's': // file size in bytes
						size = Long.parseLong(token.substring(1), 10);
						break;
					case 'm': // mod time in seconds since Jan 1, 1970 GMT
						modTime = new Date(Long.parseLong(token.substring(1), 10) * 1000);
						break;
					case ',': // separator between facts
						break;
					case '\t': // separator before file name
						if (tok.hasMoreTokens()) filename = tok.nextToken();
						break;
				}
			}
			if (filename != null) {
				return new FTPDirectoryEntry(filename, hasDirectorySemantics, hasFileSemantics, size, modTime);
			}
		} catch (NumberFormatException e) {
			// don't understand the format so ignore the line
		}
		return null;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.team.internal.ftp.client.DirectoryEntryParser#isReliable()
	 */
	public boolean isReliable() {
		return true;
	}

}
