/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.internal.target.subscriber;

import org.eclipse.core.resources.IResource;
import org.eclipse.team.core.TeamException;
import org.eclipse.team.core.subscribers.*;
import org.eclipse.team.core.synchronize.*;
import org.eclipse.team.core.variants.*;
import org.eclipse.team.core.variants.ResourceVariantTreeSubscriber;

/**
 * Override sync info such that folders that exists locally and remotely are
 * reported as in-sync
 */
public class TargetSyncInfo extends SyncInfo {

	private Subscriber subscriber;

	public TargetSyncInfo(IResource local, IResourceVariant base, IResourceVariant remote, Subscriber subscriber) {
		super(local, base, remote, ((ResourceVariantTreeSubscriber)subscriber).getResourceComparator());
		this.subscriber = subscriber;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.team.core.subscribers.SyncInfo#calculateKind(org.eclipse.core.runtime.IProgressMonitor)
	 */
	protected int calculateKind() throws TeamException {
		if (getLocal().getType() != IResource.FILE) {
			if (getLocal().exists() && getRemote() != null) {
				return IN_SYNC;
			}
		}
		return super.calculateKind();
	}

	public Subscriber getSubscriber() {
		return subscriber;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.team.core.synchronize.SyncInfo#getBase()
	 */
	public IResourceVariant getBase() {
		// If the kind has been set and there is an incoming change
		// return null as the base since the server does not keep the
		// base contents
		if ((getKind() & INCOMING) > 0) {
			return null;
		}
		return super.getBase();
	}
}
